use std::vec;

use songbird::input::YoutubeDl;
use songbird::TrackEvent;

use crate::types::{Context, ContextExt, Error};
use crate::commands::voice::voice_utils::autocomplete_channel;

use super::connect;

// For list of supported URLs visit https://github.com/yt-dlp/yt-dlp/blob/master/supportedsites.md
#[poise::command(
    slash_command,
    description_localized("en-US", "Plays music from supported URL"),
    category = "Voice",
    guild_only
)]
pub async fn play(ctx: Context<'_>,
    #[autocomplete = "autocomplete_channel"]
    #[description = "Voice channel name: "]
    channel: Option<String>,
    #[description = "Source URL: "]
    url: String,
) -> Result<(), Error> {
    let events = vec![TrackEvent::End, TrackEvent::Error];
    let (manager, guild_id) = match connect(&ctx, channel, events).await {
        Ok(result) => result,
        Err(e) => {
            ctx.reply_ephemeral(&e.to_string()).await?;
            println!("SONGBIRD MANAGER ERROR: {}", e.to_string());
            return Ok(())
        }
    };
    
    if let Some(handler_lock) = manager.get(guild_id) {
        let mut handler = handler_lock.lock().await;
        
        let http_client = &ctx.data().http_client;
        let src = YoutubeDl::new(http_client.clone(), url);
        handler.enqueue_input(src.into()).await;
    }
    else {
        ctx.reply_ephemeral("Not in a voice channel").await?;
        return Ok(())
    }

    ctx.reply_ephemeral("Done!").await?;
    Ok(())
}
