use std::collections::HashMap;

use poise::CreateReply;
use radiobrowser::RadioBrowserAPI;
use reqwest::Client as HttpClient;
use serenity::{all::{futures::lock::Mutex, GuildId}, async_trait};

use crate::commands::voice_types::PlayingInfoType;

// TODO: this should be probably expanded also to be used by multiple servers and commands
// radio and spotify commands always create new HttpClient
pub struct Data {
    pub http_client: HttpClient,
    pub radio_browser: RadioBrowserAPI,
    pub playing_info: Mutex<HashMap<GuildId, PlayingInfoType>>
}

pub type Error = Box<dyn std::error::Error + Send + Sync>;
// replace () with Data if you ever need to store some additional data
pub type Context<'a> = poise::Context<'a, Data, Error>;

/// Trait to extend `Context` with additional methods.
#[async_trait]
pub trait ContextExt {
    async fn reply_ephemeral(&self, content: &str) -> anyhow::Result<()>;
}

#[async_trait]
impl ContextExt for Context<'_> {
    async fn reply_ephemeral(&self, content: &str) -> anyhow::Result<()> {
        self.send(CreateReply::default()
            .ephemeral(true)
            .content(content)
        ).await?;
        Ok(())
    }
}
